
import sys
import datetime

sys.path.append("/ccg/src/python/lib")

from ccgdates import calendarDate, decimalDateFromDatetime

from dateutil.rrule import *


#########################################################################
class ccgFilterExportData:
    """ A class to hold all the options for exporting results. """

    def __init__(self):

	# Set any of these to what you desire, then call run()
	self.all = False	# not implemented yet
	self.unique = False	# not implemented yet
        self.cal_format = False
	self.use_hour = False
	self.user = False
	self.userfile = None
	self.outfile1 = None
	self.outfile2 = None
	self.orig = False
	self.func = False
	self.poly = False
	self.smooth = False
	self.trend = False
	self.detrend = False
	self.smcycle = False
	self.harm = False
	self.res = False
	self.smres = False
	self.trres = False
	self.ressm = False
	self.gr = False
	self.stats = False
	self.format = ""
	self.startdate = None
	self.equal = False
	self.sample = False
	self.amp = False
	self.coef = False
	self.mm = False
	self.begcoef = 0
	self.endcoef = 0
	self.include_hour = False
	self.include_header = False

    #-----------------------------------------------------------------------------------------
    def run(self, ccgfilt):

	# if self user dates or equal spaced dates aren't specified, use sample dates as default
	if not self.user and not self.equal: self.sample = True

	# If self starting date is not specified, set it to the date of the first data point 
	(syear, smonth, sday, hour, minute, second) = calendarDate(ccgfilt.xp[0])
	self.firstdate = datetime.datetime(syear, smonth, sday)
	(syear, smonth, sday, hour, minute, second) = calendarDate(ccgfilt.xp[-1])
	self.lastdate = datetime.datetime(syear, smonth, sday)
	if not self.startdate:
		self.startdate = self.firstdate

	curves = self.check_export()

	if curves:
		self.export_data(ccgfilt)

	if self.amp:
		months = [ "", "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" ]
		amps = ccgfilt.getAmplitudes()

		print " *****  Seasonal Cycle Statistics.  *****"
		print " Year      Amplitude     Maximum   Date     Minimum   Date"
		print "-----------------------------------------------------------"

		for (year, amp, maxdate, max, mindate, min) in amps:

			(yr, mnmax, dmax, hr, mn, sec) = calendarDate(maxdate)
			(yr, mnmin, dmin, hr, mn, sec) = calendarDate(mindate)

			print "%5.0f %12.2f %12.2f   %3s %2d %9.2f   %3s %2d" % (year, amp, max, months[mnmax], dmax, min, months[mnmin], dmin)

	if self.stats:
		print ccgfilt.stats()

	if self.mm:
		mm = ccgfilt.getMonthlyMeans()
		for (year, month, val, std, n) in mm:
			print "%4d %02d %7.2f %5.2f %2d" % (year, month, val, std, n)

	if self.coef:
		if self.endcoef > ccgfilt.numpm:
			e = ccgfilt.numpm
		else:
			e = self.endcoef
		
		for i in range(self.begcoef, e):
			print "%.6f" % ccgfilt.params[i],
		print


    #------------------------------------------------------------------------
    def check_export(self):

        if self.all \
	       or self.unique \
               or self.orig \
               or self.func \
               or self.poly \
               or self.smooth \
               or self.trend \
               or self.detrend \
               or self.smcycle \
               or self.harm \
               or self.res \
               or self.smres \
               or self.trres \
               or self.ressm \
               or self.gr:
		return 1
	else:
		return 0


    #------------------------------------------------------------------------
    def export_data(self, filt):

	if self.sample:
		if self.outfile1:
			try:
				fp = open(self.outfile1, "w")
			except:
				sys.exit("Can't open file %s for writing." % self.outfile1)

		else:
			fp = sys.stdout

		self.export_dates(fp, filt, filt.xp)

	if self.equal or self.user:
		if self.outfile2:
			try:
				fp = open(self.outfile2, "w")
			except:
				sys.exit("Can't open file %s for writing." % self.outfile2)

		else:
			fp = sys.stdout

		if self.equal:
			# if startdate is not equal to first date of xinterp, need to
			# create a new list of dates to give to export_dates()
			if self.startdate != self.firstdate:
				# get list of dates at sample interval
				xdates = []
				dates = rrule(DAILY, interval=filt.sampleinterval, dtstart=self.startdate, until=self.lastdate)
				for dt in dates:
					xd = decimalDateFromDatetime(dt)
					xdates.append(xd)
				self.export_dates(fp, filt, xdates)
			else:
				self.export_dates(fp, filt, filt.xinterp)
		else:
			user_x = []
			f = open(self.userfile)
			for line in f:
				a = line.split()
				xp = float(a[0])
				user_x.append(xp)
			f.close()

			self.export_dates(fp, filt, user_x)


    #----------------------------------------------------------------------
    def export_dates(self, fp, filt, x):
	""" Export (print) data to file pointer fp at dates given by x.
	The values to print are given as boolean flags in the export class.
	Some values can only be printed at sample dates, i.e. original data and residuals
	"""

	if self.include_header:
		self.export_header(fp)

	format = "%13.6e"

	h = filt.getHarmonicValue(x)	# harmonics
	p = filt.getPolyValue(x)	# poly
	s = filt.getSmoothValue(x)	# function + short term smoothing
	t = filt.getTrendValue(x)	# poly + long term smoothing
	g = filt.getGrowthRateValue(x)	# growth rate, derivative of trend
	f = filt.getFunctionValue(x)    # function
#	f = h + p			# function, poly + harmonics

	for i in range(len(x)):
		if self.cal_format:
			(yr, mon, dy, hr, mn, sec) = calendarDate(x[i])
			if self.include_hour:
				print >> fp, "%4d %02d %02d %2d" % (yr, mon, dy, hr),
			else:
				print >> fp, "%4d %02d %02d" % (yr, mon, dy),
		else:
			print >> fp, "%13.8f" % x[i],

		if self.sample and self.orig:    print >> fp, format % filt.yp[i],
		if self.func:                    print >> fp, format % f[i],
		if self.poly:                    print >> fp, format % p[i],
		if self.smooth:                  print >> fp, format % s[i],
		if self.trend:                   print >> fp, format % (t[i]),
		if self.sample and self.detrend: print >> fp, format % (filt.yp[i] - t[i]),
#		if self.smcycle:                 print >> fp, format % (h[i] + s[i] - t[i]),
		if self.smcycle:                 print >> fp, format % (s[i] - t[i]),
		if self.harm:                    print >> fp, format % (h[i]),
		if self.sample and self.res:     print >> fp, format % (filt.yp[i] - f[i]),
		if self.smres:                   print >> fp, format % (s[i] - f[i]),
		if self.trres:                   print >> fp, format % (t[i] - f[i]),
		if self.sample and self.ressm:   print >> fp, format % (filt.yp[i] - s[i]),
		if self.gr:                      print >> fp, format % (g[i]),
		

		print >> fp

    #----------------------------------------------------------------------
    def export_header(self, fp):
	""" Export a line with column header names to file pointer fp.
	"""

	format = "%-13s"

	print >> fp, format % "date",
	if self.sample and self.orig:    print >> fp, format % "value",
	if self.func:                    print >> fp, format % "function",
	if self.poly:                    print >> fp, format % "polynomial",
	if self.smooth:                  print >> fp, format % "smooth",
	if self.trend:                   print >> fp, format % "trend",
	if self.sample and self.detrend: print >> fp, format % "detrended",
	if self.smcycle:                 print >> fp, format % "smooth_cycle",
	if self.harm:                    print >> fp, format % "harmonics",
	if self.sample and self.res:     print >> fp, format % "residuals",
	if self.smres:                   print >> fp, format % "smooth_resid",
	if self.trres:                   print >> fp, format % "trend_resid",
	if self.sample and self.ressm:   print >> fp, format % "resid_smooth",
	if self.gr:                      print >> fp, format % "growth_rate",

	print >> fp
