#!/usr/bin/python

import wx
from wx.lib.wordwrap import wordwrap

from importdata import ImportDialog
from graph.graph import Graph
from graph.toolbars import ZoomToolBar
from data import processData
from reports import ReportDialog
from stats import StatsDialog
from params import Parameters, ParametersDialog
from export import ExportDialog
#from help import *

######################################################################
class Grapher(wx.Frame):
	def __init__(self, parent, ID, title):
		wx.Frame.__init__(self, parent, ID, title, wx.DefaultPosition, wx.Size(700, 550))

		self.parameters = Parameters()
		self.scstats = ""
		self.mmcstats = ""
		self.fstats = ""
		self.annstats = ""

		# Main sizer to hold toolbars and graphs
		self.sizer = wx.BoxSizer(wx.VERTICAL)

		# Make the menu bar
		self.MakeMenuBar()

		# and status bar
		self.CreateStatusBar()
		self.SetStatusText("This is the statusbar")


		# Notebook for holding graphs for the various curves
		self.nb = wx.Notebook(self, -1, style=wx.BK_DEFAULT)

		plot = Graph(self.nb, -1)
		self.nb.AddPage(plot, "Data")
		self.current_plot = plot

		plot = Graph(self.nb, -1)
		self.nb.AddPage(plot, "Seasonal Cycle")

		plot = Graph(self.nb, -1)
		self.nb.AddPage(plot, "Residuals")

		plot = Graph(self.nb, -1)
		self.nb.AddPage(plot, "Growth Rate")

		plot = Graph(self.nb, -1)
		self.nb.AddPage(plot, "Amplitude")

		plot = Graph(self.nb, -1)
		self.nb.AddPage(plot, "Filter Response")

		self.nb.Bind(wx.EVT_NOTEBOOK_PAGE_CHANGED, self.OnPageChanged)

		# Make the zoom toolbar, add to main sizer
		self.zoomtb = ZoomToolBar(self, self.current_plot)
		self.sizer.Add(self.zoomtb, 0, wx.EXPAND)
		self.sizer.Add(self.nb, 1, wx.EXPAND|wx.ALL, 5)


		self.update_menus(0)

		self.SetSizer(self.sizer)
		self.SetAutoLayout(True)
		self.Show(True)

	#----------------------------------------------
	def OnPageChanged(self, event):

		new = event.GetSelection()
		page = self.nb.GetPage(new)
		self.current_plot = page

		# Attach plot to zoom toolbar
		self.zoomtb.ClearGraphs()
		self.zoomtb.SetGraph(page)
		event.Skip()


	#----------------------------------------------
	def MakeMenuBar(self):
		self.menuBar = wx.MenuBar()

		self.file_menu = wx.Menu()
		self.menuBar.Append(self.file_menu, "&File")

		self.file_menu.Append(-1, "New", "Remove datasets and start fresh")
		self.file_menu.AppendSeparator()

#		self.file_menu.Append (102, "Open...")
		self.file_menu.Append(106, "Import...")
		self.file_menu.AppendSeparator()
		self.file_menu.Append(107, "Export...")
		self.file_menu.AppendSeparator()
		self.file_menu.Append(110, "Print Preview...")
		self.file_menu.Append(-1, "Print")

		self.file_menu.AppendSeparator()
		self.file_menu.Append(101, "Exit", "Exit the program")

#		wx.EVT_MENU(self, 102, self.getdata)
		wx.EVT_MENU(self, 106, self.importdata)
		wx.EVT_MENU(self, 107, self.exportdata)
		wx.EVT_MENU(self, 110, self.print_preview)
		wx.EVT_MENU(self, 101, self.OnExit)

		#---------------------------------------
		self.edit_menu = wx.Menu()
		self.menuBar.Append(self.edit_menu, "Edit")

		self.edit_menu.Append(200, "Parameters")
		self.edit_menu.AppendSeparator()
		self.edit_menu.Append(202, "Graph Preferences...")

		wx.EVT_MENU(self, 200, self.get_parameters)
		wx.EVT_MENU(self, 202, self.graph_prefs)

		#---------------------------------------
		menu = wx.Menu()
		self.menuBar.Append(menu, "View")

		toolbarmenu = wx.Menu()
		m = toolbarmenu.Append(1111, "Zoom Toolbar", "", wx.ITEM_CHECK)
		m.Check()
		menu.AppendMenu(-1, "Toolbars", toolbarmenu)
		wx.EVT_MENU(self, 1111, self.toggleZoomToolBar)

		#---------------------------------------
		self.report_menu = wx.Menu()
		self.menuBar.Append(self.report_menu, "Reports")

		self.report_menu.Append(501, "Filter Statistics...")
		self.report_menu.Append(502, "Data Statistics...")
		self.report_menu.Append(503, "Monthly Means...")
		self.report_menu.Append(505, "Annual Means...")
		self.report_menu.Append(504, "Seasonal Cycle...")

		wx.EVT_MENU(self, 501, self.reports)
		wx.EVT_MENU(self, 502, self.stats)
		wx.EVT_MENU(self, 503, self.reports)
		wx.EVT_MENU(self, 504, self.reports)
		wx.EVT_MENU(self, 505, self.reports)

		#---------------------------------------
		menu = wx.Menu()
		menu.Append(601, "&About...", "More information about this program")
#		menu.Append(602, "&Reference...", "More information about this program")
		self.menuBar.Append(menu, "&Help")
		wx.EVT_MENU(self, 601, self.about)
#		wx.EVT_MENU(self, 602, self.help)

		self.SetMenuBar(self.menuBar)

	#----------------------------------------------
	# Update the setting of the menu items
	# Usually called when current_plot changes or plot_list changes
	def update_menus(self, which):
		if which == 0:
			self.file_menu.Enable(107, False)
			self.report_menu.Enable(501, False)
			self.report_menu.Enable(502, False)
			self.report_menu.Enable(503, False)
			self.report_menu.Enable(504, False)
			self.report_menu.Enable(505, False)
		else:
			self.file_menu.Enable(107, True)
			self.report_menu.Enable(501, True)
			self.report_menu.Enable(502, True)
			self.report_menu.Enable(503, True)
			self.report_menu.Enable(504, True)
			self.report_menu.Enable(505, True)

	#----------------------------------------------
	def toggleZoomToolBar(self, evt):
		if evt.IsChecked():
			self.sizer.Show(self.zoomtb)
		else:
			self.sizer.Hide(self.zoomtb)
		self.sizer.Layout()

	#----------------------------------------------
	def graph_prefs(self, evt):
		self.current_plot.showPrefsDialog(evt)

	#----------------------------------------------
#	def addXAxis(self, evt):
#		self.current_plot.addXAxis("")
#		self.current_plot.update()

	#----------------------------------------------
#	def addYAxis(self, evt):
#		self.current_plot.addYAxis("")
#		self.current_plot.update()

	#----------------------------------------------
	def importdata(self, e):
		try:
			self.importdlg.graph = self.current_plot
#			self.importdlg.Show()
		except:
			self.importdlg = ImportDialog(self)
			self.importdlg.CenterOnScreen()
#			self.importdlg.Show()

		# this does not return until the dialog is closed.
		val = self.importdlg.ShowModal()

		if val == wx.ID_OK:
			self.x = self.importdlg.xdata
			self.y = self.importdlg.ydata
			self.name = self.importdlg.dataname
			processData(self, self.x, self.y, self.name)

		self.importdlg.Hide()

	#----------------------------------------------
	def OnExit(self, e):
		self.Close(True)  # Close the frame.

	#----------------------------------------------
	def print_preview(self, event):
		self.current_plot.printPreview()

	#----------------------------------------------
	def reports(self, event):
		try:
			self.reportdlg.Show()
		except:
			self.reportdlg = ReportDialog(self, -1)
			self.reportdlg.CenterOnScreen()
			self.reportdlg.Show()

		id = event.GetId()
		if id == 504:
			self.reportdlg.tc.ChangeValue(self.scstats)
		if id == 503:
			self.reportdlg.tc.ChangeValue(self.mmcstats)
		if id == 501:
			self.reportdlg.tc.ChangeValue(self.fstats)
		if id == 505:
			self.reportdlg.tc.ChangeValue(self.annstats)

	#----------------------------------------------
	def stats(self, evt):
		self.statsdlg = StatsDialog(self, -1, graph=self.current_plot)
		self.statsdlg.CenterOnScreen()
		self.statsdlg.Show()

	#----------------------------------------------
	def exportdata(self, evt):
		""" Create and show a dialog for writing out the various
		    data sets to files.
		"""

		try:
			self.exportdlg.ShowModal()
		except:
			self.exportdlg = ExportDialog(self, -1)
			self.exportdlg.CenterOnScreen()
			self.exportdlg.ShowModal()

	#----------------------------------------------
	def get_parameters(self, evt):
		""" Create and show a dialog for modifying filtering parameters
		"""

		try:
			val = self.paramsdlg.ShowModal()
		except:
			self.paramsdlg = ParametersDialog(self, -1)
			self.paramsdlg.CenterOnScreen()
			val = self.paramsdlg.ShowModal()


	#----------------------------------------------
	def about(self, evt):
		# First we create and fill the info object
		info = wx.AboutDialogInfo()
		info.Name = "CCGVU"
		info.Version = "1.0.0"
		info.Description = wordwrap(
		    "CCGvu is a program for plotting and curve fitting of the NOAA/CMDL trace gas measurements. Measurement species supported are CO2, CH4, CO, H2, and the C13 and O18 isotope measurements of CO2. Curve fits are based on a combination of a fit to the data using a function with polynomial plus annual harmonic terms, and filtering of the residuals in the frequency domain. ",

		    350, wx.ClientDC(self))
#		info.WebSite = ("http://en.wikipedia.org/wiki/Hello_world", "Hello World home page")
		info.Developers = ["Kirk Thoning NOAA/ESRL/GMD"]

#		info.License = wordwrap(licenseText, 500, wx.ClientDC(self))

		# Then we call wx.AboutBox giving it that info object
		wx.AboutBox(info)

	def help(self, evt):
		self.helpdlg = HelpDialog(self, -1)
		self.helpdlg.CenterOnScreen()
		self.helpdlg.Show()
