

import wx

from data import processData

#####################################################################3333
class Parameters:

	def __init__(self):

		self.npoly = 3
		self.nharm = 4
		self.interval = 7
		self.short = 80
		self.long = 667
		self.zero = -1.0
		self.use_gap = False
		self.gapsize = 30
		self.use_gain = False


#####################################################################3333
class ParametersDialog(wx.Dialog):
	def __init__(
		    self, parent, ID, title="Parameters", size=wx.DefaultSize, pos=wx.DefaultPosition,
		    style=wx.DEFAULT_DIALOG_STYLE|wx.RESIZE_BORDER,
            ):
		wx.Dialog.__init__(self, parent, -1, title)

		self.grapher = parent
#		self.grapher.parameters = Parameters()

		# Main sizer for dialog
		box0 = wx.BoxSizer(wx.VERTICAL)

		#------------------------------------------------
		nb = wx.Notebook(self, -1, style=wx.BK_DEFAULT)
		box0.Add(nb, 0, wx.GROW|wx.ALIGN_RIGHT|wx.ALL, 5)

		page = self.makeFunctionPage(nb)
		nb.AddPage(page, "Function")

		page = self.makeFilterPage(nb)
		nb.AddPage(page, "Filter")

		page = self.makeZeroDatePage(nb)
		nb.AddPage(page, "Zero Date")

		page = self.makeGapPage(nb)
		nb.AddPage(page, "Interpolation")

		#------------------------------------------------
		line = wx.StaticLine(self, -1, size=(20, -1), style=wx.LI_HORIZONTAL)
		box0.Add(line, 0, wx.GROW|wx.ALIGN_RIGHT|wx.RIGHT|wx.TOP, 5)

		#------------------------------------------------
		# Dialog buttons
		btnsizer = wx.StdDialogButtonSizer()

		btn = wx.Button(self, wx.ID_OK)
		btn.SetDefault()
		self.Bind(wx.EVT_BUTTON, self.ok, btn)
		btnsizer.AddButton(btn)
		btn = wx.Button(self, wx.ID_APPLY)
		self.Bind(wx.EVT_BUTTON, self.apply, btn)
		btnsizer.AddButton(btn)
		btn = wx.Button(self, wx.ID_CANCEL)
		btnsizer.AddButton(btn)

		btnsizer.Realize()

		box0.Add(btnsizer, 1, wx.ALIGN_RIGHT|wx.ALL, 5)

		self.SetSizer(box0)
		box0.SetSizeHints(self)
		box0.Fit(self)

	#---------------------------------------------------------------
	def makeFunctionPage(self, nb):

		page = wx.Panel(nb, -1)

		box0 = wx.FlexGridSizer(0, 2, 2, 2)

		#-----
		label = wx.StaticText(page, -1, "Number of Polynomial Terms:")
		box0.Add(label, 0, wx.ALIGN_CENTRE|wx.ALL, 5)
		self.npoly = wx.SpinCtrl(page, -1, str(self.grapher.parameters.npoly), size=(50, -1))
		box0.Add(self.npoly, 0, wx.ALIGN_LEFT|wx.ALL, 2)

		label = wx.StaticText(page, -1, "Number of Yearly Harmonics:")
		box0.Add(label, 0, wx.ALIGN_CENTRE|wx.ALL, 5)
		self.nharm = wx.SpinCtrl(page, -1, str(self.grapher.parameters.nharm), size=(50, -1))
		box0.Add(self.nharm, 0, wx.ALIGN_LEFT|wx.ALL, 2)

		label = wx.StaticText(page, -1, "Include Amplitude Gain Factor in function")
		box0.Add(label, 0, wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL|wx.ALL, 2)

		self.gain_checkbox = wx.CheckBox(page, -1, "")
		box0.Add(self.gain_checkbox, 0, wx.ALIGN_LEFT)
		self.gain_checkbox.SetValue(self.grapher.parameters.use_gain)


		page.SetSizer(box0)
		return page


	#---------------------------------------------------------------
	def makeFilterPage(self, nb):

		page = wx.Panel(nb, -1)

		box0 = wx.FlexGridSizer(0, 2, 2, 2)

		#-----
		label = wx.StaticText(page, -1, "Sampling Interval (Days):")
		box0.Add(label, 0, wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL|wx.ALL, 2)
		self.interval = wx.TextCtrl(page, -1, str(self.grapher.parameters.interval), size=(80, -1))
		box0.Add(self.interval, 0, wx.ALIGN_LEFT|wx.ALL, 2)

		label = wx.StaticText(page, -1, "Short Term Cutoff Value (Days):")
		box0.Add(label, 0, wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL|wx.ALL, 2)
		self.short = wx.TextCtrl(page, -1, str(self.grapher.parameters.short), size=(80, -1))
		box0.Add(self.short, 0, wx.ALIGN_LEFT|wx.ALL, 2)

		label = wx.StaticText(page, -1, "Long Term Cutoff Value (Days):")
		box0.Add(label, 0, wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL|wx.ALL, 2)
		self.long = wx.TextCtrl(page, -1, str(self.grapher.parameters.long), size=(80, -1))
		box0.Add(self.long, 0, wx.ALIGN_LEFT|wx.ALL, 2)

		page.SetSizer(box0)
		return page

	#---------------------------------------------------------------
	def makeZeroDatePage(self, nb):

		page = wx.Panel(nb, -1)

		box0 = wx.FlexGridSizer(0, 2, 2, 2)

		#-----
		label = wx.StaticText(page, -1, "Zero Date (Year):")
		box0.Add(label, 0, wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL|wx.ALL, 2)
		self.zero = wx.TextCtrl(page, -1, str(self.grapher.parameters.zero), size=(80, -1))
		box0.Add(self.zero, 0, wx.ALIGN_LEFT|wx.ALL, 2)

		page.SetSizer(box0)
		return page


	#---------------------------------------------------------------
	def makeGapPage(self, nb):

		page = wx.Panel(nb, -1)

		box0 = wx.FlexGridSizer(0, 2, 2, 2)

		#-----

		self.checkbox = wx.CheckBox(page, -1, "")
		box0.Add(self.checkbox, 0, wx.ALIGN_RIGHT)
		self.checkbox.SetValue(self.grapher.parameters.use_gap)

		label = wx.StaticText(page, -1, "Fill large gaps with function values")
		box0.Add(label, 0, wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL|wx.ALL, 2)

		label = wx.StaticText(page, -1, "Gap Size (Days):")
		box0.Add(label, 0, wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL|wx.ALL, 2)
		self.gap = wx.TextCtrl(page, -1, str(self.grapher.parameters.gapsize), size=(80, -1))
		box0.Add(self.gap, 0, wx.ALIGN_LEFT|wx.ALL, 2)

		page.SetSizer(box0)
		return page

	#---------------------------------------------------------------
	def apply(self, event):

		val = self.npoly.GetValue()
		self.grapher.parameters.npoly = int(val)

		val = self.nharm.GetValue()
		self.grapher.parameters.nharm = int(val)

		self.grapher.parameters.use_gain = self.gain_checkbox.GetValue()

		val = self.interval.GetValue()
		self.grapher.parameters.interval = float(val)

		val = self.short.GetValue()
		self.grapher.parameters.short = int(val)

		val = self.long.GetValue()
		self.grapher.parameters.long = int(val)

		val = self.zero.GetValue()
		self.grapher.parameters.zero = float(val)

		self.grapher.parameters.use_gap = self.checkbox.GetValue()
		if self.grapher.parameters.use_gap:
			val = self.gap.GetValue()
			self.grapher.parameters.gapsize = int(val)

		# Recalulate the curves
#		self.processdata()
		if hasattr(self.grapher, 'x'):
			processData(self.grapher, self.grapher.x, self.grapher.y, self.grapher.name)


	def ok(self, event):
		self.apply(event)
		self.EndModal(wx.ID_OK)
